@@ -40,12 +40,13 @@ class Secret:
             string_data=data,
             metadata=kubernetes.client.V1ObjectMeta(name=self.secret_name),
             type="Opaque")
-        core_v1_api = get_k8s_core_v1_api()
-        core_v1_api.api_client.call_api(
-            '/api/v1/namespaces/%s/secrets' % global_config["namespace"],
-            'POST', body=secret, response_type='V1Secret',
-            header_params=global_config["http_headers"],
-            _return_http_data_only=True)
+        with get_k8s_client() as k8s_client:
+            core_v1_api = kubernetes.client.CoreV1Api(k8s_client)
+            core_v1_api.api_client.call_api(
+                '/api/v1/namespaces/%s/secrets' % global_config["namespace"],
+                'POST', body=secret, response_type='V1Secret',
+                header_params=global_config["http_headers"],
+                _return_http_data_only=True)
 
 
 def get_k8s_client(k8s_api_server=None, token=None, k8s_config_file=None):
@@ -71,17 +72,6 @@ def get_k8s_client(k8s_api_server=None, token=None, k8s_config_file=None):
             config_file=k8s_config_file)
 
 
-def get_k8s_core_v1_api(k8s_api_server=None, token=None, k8s_config_file=None):
-    k8s_client = get_k8s_client(k8s_api_server, token, k8s_config_file)
-    return kubernetes.client.CoreV1Api(k8s_client)
-
-
-def get_k8s_dynamic_client(k8s_api_server=None, token=None,
-                           k8s_config_file=None):
-    k8s_client = get_k8s_client(k8s_api_server, token, k8s_config_file)
-    return kubernetes.dynamic.DynamicClient(k8s_client)
-
-
 class OPTemplate:
     def __init__(
             self,
